<?php

/*************************************************************
*  TorrentFlux - PHP Torrent Manager
*  www.torrentflux.com
**************************************************************/
/*
    This file is part of TorrentFlux.

    TorrentFlux is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    TorrentFlux is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with TorrentFlux; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

include_once("config.php");
include_once("functions.php");

if(!IsAdmin())
{
 	// the user probably hit this page direct
	AuditAction($cfg["constants"]["access_denied"], $_SERVER['PHP_SELF']);
	header("location: index.php");
}

//****************************************************************************
// addLink -- adding a link
//****************************************************************************
function addLink($newLink)
{
	global $cfg;
	addNewLink($newLink);
	AuditAction($cfg["constants"]["admin"], "New "._LINKS_MENU.": ".$newLink);
	header("location: admin.php?op=editLinks");
}

//****************************************************************************
// addRSS -- adding a RSS link
//****************************************************************************
function addRSS($newRSS)
{
	global $cfg;
	addNewRSS($newRSS);
	AuditAction($cfg["constants"]["admin"], "New RSS: ".$newRSS);
	header("location: admin.php?op=editRSS");
}

//****************************************************************************
// addUser -- adding a user
//****************************************************************************
function addUser($newUser, $pass1, $userType)
{
	global $cfg;
	$newUser = strtolower($newUser);
	If (IsUser($newUser))
	{
		DisplayHead(_ADMINISTRATION);

		// Admin Menu
		displayMenu();

		echo "<br><div align=\"center\">"._TRYDIFFERENTUSERID."<br><strong>".$newUser."</strong> "._HASBEENUSED."</div><br><br><br>";

		DisplayFoot();
	}
	else
	{
		addNewUser($newUser, $pass1, $userType);
		AuditAction($cfg["constants"]["admin"], _NEWUSER.": ".$newUser);
		header("location: admin.php?op=CreateUser");
	}
}

//****************************************************************************
// updateUser -- updating a user
//****************************************************************************
function updateUser($user_id, $org_user_id, $pass1, $userType, $hideOffline)
{
	global $cfg;
	$user_id = strtolower($user_id);
	If (IsUser($user_id) && ($user_id != $org_user_id))
	{
		DisplayHead(_ADMINISTRATION);

		// Admin Menu
		displayMenu();

		echo "<br><div align=\"center\">"._TRYDIFFERENTUSERID."<br><strong>".$user_id."</strong> "._HASBEENUSED."<br><br><br>";

		echo "[<a href=\"admin.php?op=editUser&user_id=".$org_user_id."\">"._RETURNTOEDIT." ".$org_user_id."</a>]</div><br><br><br>";

		DisplayFoot();
	}
	else
	{
		// Admin is changing id or password through edit screen
		if(($user_id == $cfg["user"] || $cfg["user"] == $org_user_id) && $pass1 != "")
		{
			// this will expire the user
			$_SESSION['user'] = md5($cfg["pagetitle"]);
		}
		updateThisUser($user_id, $org_user_id, $pass1, $userType, $hideOffline);
		AuditAction($cfg["constants"]["admin"], _EDITUSER.": ".$user_id);
		header("location: admin.php");
	}
}

//****************************************************************************
// deleteLink -- delete a link
//****************************************************************************
function deleteLink($lid)
{
	global $cfg;
	AuditAction($cfg["constants"]["admin"], _DELETE." Link: ".getLink($lid));
	deleteOldLink($lid);
	header("location: admin.php?op=editLinks");
}

//****************************************************************************
// deleteRSS -- delete a RSS link
//****************************************************************************
function deleteRSS($rid)
{
	global $cfg;
	AuditAction($cfg["constants"]["admin"], _DELETE." RSS: ".getRSS($rid));
	deleteOldRSS($rid);
	header("location: admin.php?op=editRSS");
}

//****************************************************************************
// deleteUser -- delete a user (only non super admin)
//****************************************************************************
function deleteUser($user_id)
{
	global $cfg;
	if (!IsSuperAdmin($user_id))
	{
		DeleteThisUser($user_id);
		AuditAction($cfg["constants"]["admin"], _DELETE." "._USER.": ".$user_id);
	}
	header("location: admin.php");
}

//****************************************************************************
// showIndex -- default view
//****************************************************************************
function showIndex($min)
{
	global $cfg;
	DisplayHead(_ADMINISTRATION);

	// Admin Menu
	displayMenu();

	// Show User Section
	displayUserSection();

	echo "<br>";

	// Display Activity
	displayActivity($min);

	DisplayFoot();

}


//****************************************************************************
// showUserActivity -- Activity for a user
//****************************************************************************
function showUserActivity($min, $user_id, $srchFile, $srchAction)
{
	global $cfg;

	DisplayHead(_ADMINUSERACTIVITY);

	// Admin Menu
	displayMenu();

	// display Activity for user
	displayActivity($min, $user_id, $srchFile, $srchAction);

	DisplayFoot();

}



//****************************************************************************
// backupDatabase -- backup the database
//****************************************************************************
function backupDatabase()
{
	global $cfg;

	$file = $cfg["db_name"]."_".date("Ymd").".tar.gz";
	$back_file = $cfg["torrent_file_path"].$file;
	$sql_file = $cfg["torrent_file_path"].$cfg["db_name"].".sql";
	
	$sCommand = "";
	switch($cfg["db_type"])
	{
		case "mysql":
			$sCommand = "mysqldump -h ".$cfg["db_host"]." -u ".$cfg["db_user"]." --password=".$cfg["db_pass"]." --all -f ".$cfg["db_name"]." > ".$sql_file;
			break;
		default:
			// no support for backup-on-demand.
			$sCommand = "";
			break;
	}

	if($sCommand != "")
	{
		shell_exec($sCommand);
		shell_exec("tar -czvf ".$back_file." ".$sql_file);

		// Get the file size
		$file_size = filesize($back_file);

		// open the file to read
		$fo = fopen($back_file, r);
		$fr = fread($fo, $file_size);
		fclose($fo);

		// Set the headers
		header("Content-type: APPLICATION/OCTET-STREAM");
		header("Content-Length: ".$file_size.";");
		header("Content-Disposition: attachement; filename=".$file);
	
		// send the tar baby
		echo $fr;
	
		// Cleanup
		shell_exec("rm ".$sql_file);
		shell_exec("rm ".$back_file);
		AuditAction($cfg["constants"]["admin"], _BACKUP_MENU.": ".$file);
	}
}


//****************************************************************************
// displayMenu -- displays Admin Menu
//****************************************************************************
function displayMenu()
{
	global $cfg;
	echo "<table width=\"760\" border=1 bordercolor=\"".$cfg["table_admin_border"]."\" cellpadding=\"2\" cellspacing=\"0\">";
	echo "<tr><td colspan=6 bgcolor=\"".$cfg["table_header_bg"]."\" background=\"themes/".$cfg["theme"]."/images/bar.gif\"><div align=\"center\">";
	echo "<a href=\"admin.php\"><font class=\"adminlink\">"._ADMIN_MENU."</font></a> | ";
	echo "<a href=\"admin.php?op=showUserActivity\"><font class=\"adminlink\">"._ACTIVITY_MENU."</font></a> | ";
	echo "<a href=\"admin.php?op=editLinks\"><font class=\"adminlink\">"._LINKS_MENU."</font></a> | ";
	echo "<a href=\"admin.php?op=editRSS\"><font class=\"adminlink\">RSS</font></a> | ";
	echo "<a href=\"admin.php?op=CreateUser\"><font class=\"adminlink\">"._NEWUSER_MENU."</font></a> | ";
	echo "<a href=\"admin.php?op=backupDatabase\"><font class=\"adminlink\">"._BACKUP_MENU."</font></a>";
	echo "</div></td></tr>";
	echo "</table><br>";

}


//****************************************************************************
// displayActivity -- displays Activity
//****************************************************************************
function displayActivity($min, $user="", $srchFile="", $srchAction="")
{
	global $cfg, $db;

	$sqlForSearch = "";

	$userdisplay = $user;

	if($user != "")
	{
		$sqlForSearch .= "user_id='".$user."' AND ";
	}
	else
	{
		$userdisplay = _ALLUSERS;
	}

	if($srchFile != "")
	{
		$sqlForSearch .= "file like '%".$srchFile."%' AND ";
	}

	if($srchAction != "")
	{
		$sqlForSearch .= "action like '%".$srchAction."%' AND ";
	}

	$offset = 50;
	$inx = 0;
	if (!isset($min)) $min=0;
	$max = $min+$offset;
	$output = "";
	$morelink = "";

	$sql = "SELECT cid, user_id, file, action, ip, ip_resolved, user_agent, time FROM tf_log WHERE ".$sqlForSearch."action!=".$db->qstr($cfg["constants"]["hit"])." ORDER BY time desc";

	$result = $db->SelectLimit($sql, $offset, $min);
	while(list($cid, $user_id, $file, $action, $ip, $ip_resolved, $user_agent, $time) = $result->FetchRow())
	{
		$user_icon = "images/user_offline.gif";
		if (IsOnline($user_id))
		{
			$user_icon = "images/user.gif";
		}

		$ip_info = $ip_resolved."<br>".$user_agent;

		$output .= "<tr>";
		if (IsUser($user_id))
		{
			$output .= "<td><a href=\"message.php?to_user=".$user_id."\"><img src=\"".$user_icon."\" width=17 height=14 title=\""._SENDMESSAGETO." ".$user_id."\" border=0 align=\"bottom\">".$user_id."</a>&nbsp;&nbsp;</td>";
		}
		else
		{
			$output .= "<td><img src=\"".$user_icon."\" width=17 height=14 title=\"n/a\" border=0 align=\"bottom\">".$user_id."&nbsp;&nbsp;</td>";
		}
		$output .= "<td><div class=\"tiny\">".$action."</div></td>";
		$output .= "<td><div align=center><div class=\"tiny\" align=\"left\">";
		$output .= $file;
		$output .= "</div></td>";
		$output .= "<td><div class=\"tiny\" align=\"left\"><a href=\"javascript:void(0)\" onclick=\"return overlib('".$ip_info."<br>', STICKY, CSSCLASS);\" onmouseover=\"return overlib('".$ip_info."<br>', CSSCLASS);\" onmouseout=\"return nd();\"><img src=\"images/properties.png\" width=\"18\" height=\"13\" border=\"0\"><font class=tiny>".$ip."</font></a></div></td>";
		$output .= "<td><div class=\"tiny\" align=\"center\">".date(_DATETIMEFORMAT, $time)."</div></td>";
		$output .= "</tr>";

		$inx++;
	}

	if($inx == 0)
	{
		$output = "<tr><td colspan=6><center><strong>-- "._NORECORDSFOUND." --</strong></center></td></tr>";
	}

	$prev = ($min-$offset);
	if ($prev>=0)
	{
		$prevlink = "<a href=\"admin.php?op=showUserActivity&min=".$prev."&user_id=".$user."&srchFile=".$srchFile."&srchAction=".$srchAction."\">";
		$prevlink .= "<font class=\"TinyWhite\">&lt;&lt;".$min." "._SHOWPREVIOUS."]</font></a> &nbsp;";
	}
	$next=$min+$offset;
	if ($inx>=$offset)
	{
		$morelink = "<a href=\"admin.php?op=showUserActivity&min=".$max."&user_id=".$user."&srchFile=".$srchFile."&srchAction=".$srchAction."\">";
		$morelink .= "<font class=\"TinyWhite\">["._SHOWMORE."&gt;&gt;</font></a>";
	}
?>
	<div id="overDiv" style="position:absolute;visibility:hidden;z-index:1000;"></div>
	<script language="JavaScript">
		var ol_closeclick = "1";
		var ol_close = "<font color=#ffffff><b>X</b></font>";
		var ol_fgclass = "fg";
		var ol_bgclass = "bg";
		var ol_captionfontclass = "overCaption";
		var ol_closefontclass = "overClose";
		var ol_textfontclass = "overBody";
		var ol_cap = "&nbsp;IP Info";
	</script>
	<script src="overlib.js" type="text/javascript"></script>
	<div align="center">
	<table>
	<form action="admin.php?op=showUserActivity" name="searchForm" method="post">
	<tr>
		<td>
		<strong><?php echo _ACTIVITYSEARCH ?></strong>&nbsp;&nbsp;&nbsp;
		<?php echo _FILE ?>:
		<input type="Text" name="srchFile" value="<?php echo $srchFile ?>" width="30"> &nbsp;&nbsp;
		<?php echo _ACTION ?>:
		<select name="srchAction">
		<option value="">-- <?php echo _ALL ?> --</option>
<?php
		$selected = "";
		foreach ($cfg["constants"] as $action)
		{
			$selected = "";
			if($action != $cfg["constants"]["hit"])
			{
				if($srchAction == $action)
				{
					$selected = "selected";
				}
				echo "<option value=\"".$action."\" ".$selected.">".$action."</option>";
			}
		}
?>
		</select>&nbsp;&nbsp;
		<?php echo _USER ?>:
		<select name="user_id">
		<option value="">-- <?php echo _ALL ?> --</option>
<?php
		$users = GetUsers();
		$selected = "";
		for($inx = 0; $inx < sizeof($users); $inx++)
		{
			$selected = "";
			if($user == $users[$inx])
			{
				$selected = "selected";
			}
			echo "<option value=\"".$users[$inx]."\" ".$selected.">".$users[$inx]."</option>";
		}
?>
		</select>
		<input type="Submit" value="<?php echo _SEARCH ?>">

		</td>
	</tr>
	</form>
	</table>
	</div>


<?php
	echo "<table width=\"760\" border=1 bordercolor=\"".$cfg["table_admin_border"]."\" cellpadding=\"2\" cellspacing=\"0\" bgcolor=\"".$cfg["table_data_bg"]."\">";
	echo "<tr><td colspan=6 bgcolor=\"".$cfg["table_header_bg"]."\" background=\"themes/".$cfg["theme"]."/images/bar.gif\">";
	echo "<table width=\"100%\" cellpadding=0 cellspacing=0 border=0><tr><td>";
	echo "<img src=\"images/properties.png\" width=18 height=13 border=0>&nbsp;&nbsp;<font class=\"title\">"._ACTIVITYLOG." ".$cfg["days_to_keep"]." "._DAYS." (".$userdisplay.")</font>";
	echo "</td><td align=\"right\">".$prevlink.$morelink."</td></tr></table>";
	echo "</td></tr>";
	echo "<tr>";
	echo "<td bgcolor=\"".$cfg["table_header_bg"]."\"><div align=center class=\"title\">"._USER."</div></td>";
	echo "<td bgcolor=\"".$cfg["table_header_bg"]."\"><div align=center class=\"title\">"._ACTION."</div></td>";
	echo "<td bgcolor=\"".$cfg["table_header_bg"]."\"><div align=center class=\"title\">"._FILE."</div></td>";
	echo "<td bgcolor=\"".$cfg["table_header_bg"]."\" width=\"13%\"><div align=center class=\"title\">"._IP."</div></td>";
	echo "<td bgcolor=\"".$cfg["table_header_bg"]."\" width=\"15%\"><div align=center class=\"title\">"._TIMESTAMP."</div></td>";
	echo "</tr>";

	echo $output;

	if(!empty($prevlink) || !empty($morelink))
	{
		echo "<tr><td colspan=6 bgcolor=\"".$cfg["table_header_bg"]."\">";
		echo "<table width=\"100%\" cellpadding=0 cellspacing=0 border=0><tr><td align=\"left\">";
		echo $prevlink;
		echo "</td><td align=\"right\">";
		echo $morelink;
		echo "</td></tr></table>";
		echo "</td></tr>";
	}

	echo "</table>";

}



//****************************************************************************
// displayUserSection -- displays the user section
//****************************************************************************
function displayUserSection()
{
	global $cfg, $db;

	echo "<table width=\"760\" border=1 bordercolor=\"".$cfg["table_admin_border"]."\" cellpadding=\"2\" cellspacing=\"0\" bgcolor=\"".$cfg["table_data_bg"]."\">";
	echo "<tr><td colspan=6 bgcolor=\"".$cfg["table_header_bg"]."\" background=\"themes/".$cfg["theme"]."/images/bar.gif\"><img src=\"images/user_group.gif\" width=17 height=14 border=0>&nbsp;&nbsp;<font class=\"title\">"._USERDETAILS."</font></div></td></tr>";
	echo "<tr>";
	echo "<td bgcolor=\"".$cfg["table_header_bg"]."\" width=\"15%\"><div align=center class=\"title\">"._USER."</div></td>";
	echo "<td bgcolor=\"".$cfg["table_header_bg"]."\" width=\"6%\"><div align=center class=\"title\">"._HITS."</div></td>";
	echo "<td bgcolor=\"".$cfg["table_header_bg"]."\"><div align=center class=\"title\">"._UPLOADACTIVITY." (".$cfg["days_to_keep"]." "._DAYS.")</div></td>";
	echo "<td bgcolor=\"".$cfg["table_header_bg"]."\" width=\"6%\"><div align=center class=\"title\">"._JOINED."</div></td>";
	echo "<td bgcolor=\"".$cfg["table_header_bg"]."\" width=\"15%\"><div align=center class=\"title\">"._LASTVISIT."</div></td>";
	echo "<td bgcolor=\"".$cfg["table_header_bg"]."\" width=\"8%\"><div align=center class=\"title\">"._ADMIN."</div></td>";
	echo "</tr>";

	$total_activity = GetActivityCount();

	$sql= "SELECT user_id, hits, last_visit, time_created, user_level FROM tf_users ORDER BY user_id";
	$result = $db->Execute($sql);
	while(list($user_id, $hits, $last_visit, $time_created, $user_level) = $result->FetchRow())
	{
		$user_activity = GetActivityCount($user_id);

		if ($user_activity == 0)
		{
			$user_percent = 0;
		}
		else
		{
			$user_percent = number_format(($user_activity/$total_activity)*100);
		}
		$user_icon = "images/user_offline.gif";
		if (IsOnline($user_id))
		{
			$user_icon = "images/user.gif";
		}

		echo "<tr>";
		if (IsUser($user_id))
		{
			echo "<td><a href=\"message.php?to_user=".$user_id."\"><img src=\"".$user_icon."\" width=17 height=14 title=\""._SENDMESSAGETO." ".$user_id."\" border=0 align=\"bottom\">".$user_id."</a></td>";
		}
		else
		{
			echo "<td><img src=\"".$user_icon."\" width=17 height=14 title=\"n/a\" border=0 align=\"bottom\">".$user_id."</td>";
		}
		echo "<td><div class=\"tiny\" align=\"right\">".$hits."</div></td>";
		echo "<td><div align=center>";
?>
		<table width="310" border="0" cellpadding="0" cellspacing="0">
		<tr>
		<td width="200">
			<table width="200" border="0" cellpadding="0" cellspacing="0">
			<tr>
				<td background="themes/<?php echo $cfg["theme"] ?>/images/proglass.gif" width="<?php echo $user_percent*2 ?>"><img src="images/blank.gif" width="1" height="12" border="0"></td>
				<td background="themes/<?php echo $cfg["theme"] ?>/images/noglass.gif" width="<?php echo (200 - ($user_percent*2)) ?>"><img src="images/blank.gif" width="1" height="12" border="0"></td>
			</tr>
			</table>
		</td>
		<td align="right" width="40"><div class="tiny" align="right"><?php echo $user_activity ?></div></td>
		<td align="right" width="40"><div class="tiny" align="right"><?php echo $user_percent ?>%</div></td>
		<td align="right"><a href="admin.php?op=showUserActivity&user_id=<?php echo $user_id ?>"><img src="images/properties.png" width="18" height="13" title="<?php echo $user_id."'s "._USERSACTIVITY ?>" border="0"></a></td>
		</tr>
		</table>
<?php
		echo "</td>";
		echo "<td><div class=\"tiny\" align=\"center\">".date(_DATEFORMAT, $time_created)."</div></td>";
		echo "<td><div class=\"tiny\" align=\"center\">".date(_DATETIMEFORMAT, $last_visit)."</div></td>";
		echo "<td><div align=\"right\" class=\"tiny\">";
		$user_image = "images/user.gif";
		$type_user = _NORMALUSER;
		if ($user_level == 1)
		{
			$user_image = "images/admin_user.gif";
			$type_user = _ADMINISTRATOR;
		}
		if ($user_level == 2)
		{
			$user_image = "images/superadmin.gif";
			$type_user = _SUPERADMIN;
		}
		if ($user_level <= 1 || IsSuperAdmin())
		{
			echo "<a href=\"admin.php?op=editUser&user_id=".$user_id."\"><img src=\"images/edit.png\" width=12 height=13 title=\""._EDIT." ".$user_id."\" border=0></a>";
		}
		echo "<img src=\"".$user_image."\" title=\"".$user_id." - ".$type_user."\">";
		if ($user_level <= 1)
		{
			echo "<a href=\"admin.php?op=deleteUser&user_id=".$user_id."\"><img src=\"images/delete_on.gif\" border=0 width=16 height=16 title=\""._DELETE." ".$user_id."\" onclick=\"return ConfirmDeleteUser('".$user_id."')\"></a>";
		}
		else
		{
			echo "<img src=\"images/delete_off.gif\" width=16 height=16 title=\"n/a\">";
		}

		echo "</div></td>";
		echo "</tr>";
	}

	echo "</table>";
?>
	<script language="JavaScript">
	function ConfirmDeleteUser(user)
	{
		return confirm("<?php echo _WARNING.": "._ABOUTTODELETE ?>: " + user)
	}
	</script>
<?php
}


//****************************************************************************
// editUser -- edit a user
//****************************************************************************
function editUser($user_id)
{
	global $cfg, $db;
	DisplayHead(_USERADMIN);

	$editUserImage = "images/user.gif";
	$selected_n = "selected";
	$selected_a = "";

	$hide_checked = "";

	// Admin Menu
	displayMenu();

	$total_activity = GetActivityCount();

	$sql= "SELECT user_id, hits, last_visit, time_created, user_level, hide_offline, theme, language_file FROM tf_users WHERE user_id=".$db->qstr($user_id);

	list($user_id, $hits, $last_visit, $time_created, $user_level, $hide_offline, $theme, $language_file) = $db->GetRow($sql);

	$user_type = _NORMALUSER;
	if ($user_level == 1)
	{
		$user_type = _ADMINISTRATOR;
		$selected_n = "";
		$selected_a = "selected";
		$editUserImage = "images/admin_user.gif";
	}
	if ($user_level >= 2)
	{
		$user_type = _SUPERADMIN;
		$editUserImage = "images/superadmin.gif";
	}

	if ($hide_offline == 1)
	{
		$hide_checked = "checked";
	}


	$user_activity = GetActivityCount($user_id);

	if ($user_activity == 0)
	{
		$user_percent = 0;
	}
	else
	{
		$user_percent = number_format(($user_activity/$total_activity)*100);
	}

	echo "<div align=\"center\">";
	echo "<table width=\"100%\" border=1 bordercolor=\"".$cfg["table_admin_border"]."\" cellpadding=\"2\" cellspacing=\"0\" bgcolor=\"".$cfg["table_data_bg"]."\">";
	echo "<tr><td colspan=6 bgcolor=\"".$cfg["table_header_bg"]."\" background=\"themes/".$cfg["theme"]."/images/bar.gif\">";
	echo "<img src=\"".$editUserImage."\" width=17 height=14 border=0>&nbsp;&nbsp;&nbsp;<font class=\"title\">"._EDITUSER.": ".$user_id."</font>";
	echo "</td></tr><tr><td align=\"center\">";
?>

	<table width="100%" border="0" cellpadding="3" cellspacing="0">
	<tr>
		<td width="50%" bgcolor="<?php echo $cfg["table_data_bg"]?>" valign="top">

		<div align="center">
		<table border="0" cellpadding="0" cellspacing="0">
		<tr>
			<td align="right"><?php echo $user_id." "._JOINED ?>:&nbsp;</td>
			<td><strong><?php echo date(_DATETIMEFORMAT, $time_created) ?></strong></td>
		</tr>
		<tr>
			<td align="right"><?php echo _LASTVISIT ?>:&nbsp;</td>
			<td><strong><?php echo date(_DATETIMEFORMAT, $last_visit) ?></strong></td>
		</tr>
		<tr>
			<td colspan="2" align="center">&nbsp;</td>
		</tr>
		<tr>
			<td align="right"><?php echo _UPLOADPARTICIPATION ?>:&nbsp;</td>
			<td>
				<table width="200" border="0" cellpadding="0" cellspacing="0">
				<tr>
					<td background="themes/<?php echo $cfg["theme"] ?>/images/proglass.gif" width="<?php echo $user_percent*2 ?>"><img src="images/blank.gif" width="1" height="12" border="0"></td>
					<td background="themes/<?php echo $cfg["theme"] ?>/images/noglass.gif" width="<?php echo (200 - ($user_percent*2)) ?>"><img src="images/blank.gif" width="1" height="12" border="0"></td>
				</tr>
				</table>
			</td>
		</tr>
		<tr>
			<td align="right"><?php echo _UPLOADS ?>:&nbsp;</td>
			<td><strong><?php echo $user_activity ?></strong></td>
		</tr>
		<tr>
			<td align="right"><?php echo _PERCENTPARTICIPATION ?>:&nbsp;</td>
			<td><strong><?php echo $user_percent ?>%</strong></td>
		</tr>
		<tr>
			<td colspan="2" align="center"><div align="center" class="tiny">(<?php echo _PARTICIPATIONSTATEMENT. " ".$cfg['days_to_keep']." "._DAYS ?>)</div><br></td>
		</tr>
		<tr>
			<td align="right"><?php echo _TOTALPAGEVIEWS ?>:&nbsp;</td>
			<td><strong><?php echo $hits ?></strong></td>
		</tr>
		<tr>
			<td align="right" valign="top"><?php echo _THEME ?>:&nbsp;</td>
			<td valign="top"><strong><?php echo $theme ?></strong><br></td>
		</tr>
		<tr>
			<td align="right" valign="top"><?php echo _LANGUAGE ?>:&nbsp;</td>
			<td valign="top"><strong><?php echo GetLanguageFromFile($language_file) ?></strong><br><br></td>
		</tr>
		<tr>
			<td align="right" valign="top"><?php echo _USERTYPE ?>:&nbsp;</td>
			<td valign="top"><strong><?php echo $user_type ?></strong><br></td>
		</tr>
		<tr>
			<td colspan="2" align="center"><div align="center">[<a href="admin.php?op=showUserActivity&user_id=<?php echo $user_id ?>"><?php echo _USERSACTIVITY ?></a>]</div></td>
		</tr>
		</table>
		</div>

		</td>
		<td valign="top" bgcolor="<?php echo $cfg["body_data_bg"] ?>">
		<div align="center">
		<table cellpadding="5" cellspacing="0" border="0">
		<form name="theForm" action="admin.php?op=updateUser" method="post" onsubmit="return validateUser()">
		<tr>
			<td align="right"><?php echo _USER ?>:</td>
			<td>
			<input name="user_id" type="Text" value="<?php echo $user_id ?>" size="15">
			<input name="org_user_id" type="Hidden" value="<?php echo $user_id ?>">
			</td>
		</tr>
		<tr>
			<td align="right"><?php echo _NEWPASSWORD ?>:</td>
			<td>
			<input name="pass1" type="Password" value="" size="15">
			</td>
		</tr>
		<tr>
			<td align="right"><?php echo _CONFIRMPASSWORD ?>:</td>
			<td>
			<input name="pass2" type="Password" value="" size="15">
			</td>
		</tr>
		<tr>
			<td align="right"><?php echo _USERTYPE ?>:</td>
			<td>
<?php if ($user_level <= 1) { ?>
			<select name="userType">
				<option value="0" <?php echo $selected_n ?>><?php echo _NORMALUSER ?></option>
				<option value="1" <?php echo $selected_a ?>><?php echo _ADMINISTRATOR ?></option>
			</select>
<?php } else { ?>
			<strong><?php echo _SUPERADMIN ?></strong>
			<input type="Hidden" name="userType" value="2">
<?php } ?>
			</td>
		</tr>
		<tr>
			<td colspan="2">
			<input name="hideOffline" type="Checkbox" value="1" <?php echo $hide_checked ?>> <?php echo _HIDEOFFLINEUSERS ?><br>
			</td>
		</tr>
		<tr>
			<td align="center" colspan="2">
			<input type="Submit" value="<?php echo _UPDATE ?>">
			</td>
		</tr>
		</form>
		</table>
		</div>
		</td>
	</tr>
	</table>


	<script language="JavaScript">
	function validateUser()
	{
		var msg = ""
		if (theForm.user_id.value == "")
		{
			msg = msg + "* <?php echo _USERIDREQUIRED ?>\n";
			theForm.user_id.focus();
		}

		if (theForm.pass1.value != "" || theForm.pass2.value != "")
		{
			if (theForm.pass1.value.length <= 5 || theForm.pass2.value.length <= 5)
			{
				msg = msg + "* <?php echo _PASSWORDLENGTH ?>\n";
				theForm.pass1.focus();
			}
			if (theForm.pass1.value != theForm.pass2.value)
			{
				msg = msg + "* <?php echo _PASSWORDNOTMATCH ?>\n";
				theForm.pass1.value = "";
				theForm.pass2.value = "";
				theForm.pass1.focus();
			}
		}

		if (msg != "")
		{
			alert("<?php echo _PLEASECHECKFOLLOWING ?>:\n\n" + msg);
			return false;
		}
		else
		{
			return true;
		}
	}
	</script>

<?php
	echo "</td></tr>";
	echo "</table></div>";
	echo "<br><br>";

	// Show User Section
	displayUserSection();

	echo "<br><br>";

	DisplayFoot();
}


//****************************************************************************
// CreateUser -- Create a user
//****************************************************************************
function CreateUser()
{
	global $cfg;
	DisplayHead(_USERADMIN);

	// Admin Menu
	displayMenu();
	echo "<div align=\"center\">";
	echo "<table border=1 bordercolor=\"".$cfg["table_admin_border"]."\" cellpadding=\"2\" cellspacing=\"0\" bgcolor=\"".$cfg["table_data_bg"]."\">";
	echo "<tr><td colspan=6 bgcolor=\"".$cfg["table_header_bg"]."\" background=\"themes/".$cfg["theme"]."/images/bar.gif\">";
	echo "<img src=\"images/user.gif\" width=17 height=14 border=0>&nbsp;&nbsp;&nbsp;<font class=\"title\">"._NEWUSER."</font>";
	echo "</td></tr><tr><td align=\"center\">";
?>
	<div align="center">
		<table cellpadding="5" cellspacing="0" border="0">
		<form name="theForm" action="admin.php?op=addUser" method="post" onsubmit="return validateProfile()">
		<tr>
			<td align="right"><?php echo _USER ?>:</td>
			<td>
			<input name="newUser" type="Text" value="" size="15">
			</td>
		</tr>
		<tr>
			<td align="right"><?php echo _PASSWORD ?>:</td>
			<td>
			<input name="pass1" type="Password" value="" size="15">
			</td>
		</tr>
		<tr>
			<td align="right"><?php echo _CONFIRMPASSWORD ?>:</td>
			<td>
			<input name="pass2" type="Password" value="" size="15">
			</td>
		</tr>
		<tr>
			<td align="right"><?php echo _USERTYPE ?>:</td>
			<td>
			<select name="userType">
				<option value="0"><?php echo _NORMALUSER ?></option>
				<option value="1"><?php echo _ADMINISTRATOR ?></option>
			</select>
			</td>
		</tr>
		<tr>
			<td align="center" colspan="2">
			<input type="Submit" value="<?php echo _CREATE ?>">
			</td>
		</tr>
		</form>
		</table>
		</div>

	<br>

	<script language="JavaScript">
	function validateProfile()
	{
		var msg = ""
		if (theForm.newUser.value == "")
		{
			msg = msg + "* <?php echo _USERIDREQUIRED ?>\n";
			theForm.newUser.focus();
		}
		if (theForm.pass1.value != "" || theForm.pass2.value != "")
		{
			if (theForm.pass1.value.length <= 5 || theForm.pass2.value.length <= 5)
			{
				msg = msg + "* <?php echo _PASSWORDLENGTH ?>\n";
				theForm.pass1.focus();
			}
			if (theForm.pass1.value != theForm.pass2.value)
			{
				msg = msg + "* <?php echo _PASSWORDNOTMATCH ?>\n";
				theForm.pass1.value = "";
				theForm.pass2.value = "";
				theForm.pass1.focus();
			}
		}
		else
		{
			msg = msg + "* <?php echo _PASSWORDLENGTH ?>\n";
			theForm.pass1.focus();
		}

		if (msg != "")
		{
			alert("<?php echo _PLEASECHECKFOLLOWING ?>:\n\n" + msg);
			return false;
		}
		else
		{
			return true;
		}
	}
	</script>

<?php
	echo "</td></tr>";
	echo "</table></div>";
	echo "<br><br>";

	// Show User Section
	displayUserSection();

	echo "<br><br>";

	DisplayFoot();
}

//****************************************************************************
// editLinks -- Edit Links
//****************************************************************************
function editLinks()
{
	global $cfg;
	DisplayHead(_ADMINEDITLINKS);

	// Admin Menu
	displayMenu();
	echo "<div align=\"center\">";
	echo "<table border=1 bordercolor=\"".$cfg["table_admin_border"]."\" cellpadding=\"2\" cellspacing=\"0\" bgcolor=\"".$cfg["table_data_bg"]."\">";
	echo "<tr><td bgcolor=\"".$cfg["table_header_bg"]."\" background=\"themes/".$cfg["theme"]."/images/bar.gif\">";
	echo "<img src=\"images/properties.png\" width=18 height=13 border=0>&nbsp;&nbsp;<font class=\"title\">"._ADMINEDITLINKS."</font>";
	echo "</td></tr><tr><td align=\"center\">";
?>
	<form action="admin.php?op=addLink" method="post">
	<?php echo _FULLURLLINK ?>:
	<input type="Text" size="50" maxlength="255" name="newLink">
	<input type="Submit" value="<?php echo _UPDATE ?>"><br>
	</form>
<?php
	echo "</td></tr>";
	$arLinks = GetLinks();
	$arLid = Array_Keys($arLinks);
	$inx = 0;
	foreach($arLinks as $link)
	{
		$lid = $arLid[$inx++];
		echo "<tr><td><a href=\"admin.php?op=deleteLink&lid=".$lid."\"><img src=\"images/delete_on.gif\" width=16 height=16 border=0 title=\""._DELETE." ".$lid."\" align=\"absmiddle\"></a>&nbsp;";
		echo "<a href=\"".$link."\" target=\"_blank\">".$link."</a></td></tr>\n";
	}

	echo "</table></div><br><br><br>";

	DisplayFoot();

}


//****************************************************************************
// editRSS -- Edit RSS Feeds
//****************************************************************************
function editRSS()
{
	global $cfg;
	DisplayHead("Administration - RSS");

	// Admin Menu
	displayMenu();
	echo "<div align=\"center\">";
	echo "<table border=1 bordercolor=\"".$cfg["table_admin_border"]."\" cellpadding=\"2\" cellspacing=\"0\" bgcolor=\"".$cfg["table_data_bg"]."\">";
	echo "<tr><td bgcolor=\"".$cfg["table_header_bg"]."\" background=\"themes/".$cfg["theme"]."/images/bar.gif\">";
	echo "<img src=\"images/properties.png\" width=18 height=13 border=0>&nbsp;&nbsp;<font class=\"title\">RSS Feeds</font>";
	echo "</td></tr><tr><td align=\"center\">";
?>
	<form action="admin.php?op=addRSS" method="post">
	<?php echo _FULLURLLINK ?>:
	<input type="Text" size="50" maxlength="255" name="newRSS">
	<input type="Submit" value="<?php echo _UPDATE ?>"><br>
	</form>
<?php
	echo "</td></tr>";
	$arLinks = GetRSSLinks();
	$arRid = Array_Keys($arLinks);
	$inx = 0;
	foreach($arLinks as $link)
	{
		$rid = $arRid[$inx++];
		echo "<tr><td><a href=\"admin.php?op=deleteRSS&rid=".$rid."\"><img src=\"images/delete_on.gif\" width=16 height=16 border=0 title=\""._DELETE." ".$rid."\" align=\"absmiddle\"></a>&nbsp;";
		echo "<a href=\"".$link."\" target=\"_blank\">".$link."</a></td></tr>\n";
	}

	echo "</table></div><br><br><br>";

	DisplayFoot();

}


//****************************************************************************
//****************************************************************************
//****************************************************************************
//****************************************************************************
// TRAFFIC CONTROLER
switch ($op) {

    default:
    	showIndex($min);
    break;

    case "showUserActivity":
    	showUserActivity($min, $user_id, $srchFile, $srchAction);
    break;

	case "backupDatabase":
    	backupDatabase();
    break;

	case "editRSS":
		editRSS();
	break;

	case "addRSS":
		addRSS($newRSS);
	break;

	case "deleteRSS":
		deleteRSS($rid);
	break;

	case "editLinks":
		editLinks();
	break;

	case "addLink":
		addLink($newLink);
	break;

	case "deleteLink":
		deleteLink($lid);
	break;

	case "CreateUser":
		CreateUser();
	break;

	case "addUser":
		addUser($newUser, $pass1, $userType);
	break;

	case "deleteUser":
		deleteUser($user_id);
	break;

	case "editUser":
		editUser($user_id);
	break;

	case "updateUser":
		updateUser($user_id, $org_user_id, $pass1, $userType, $hideOffline);
	break;
}
//****************************************************************************
//****************************************************************************
//****************************************************************************
//****************************************************************************

?>